==> entodicton-5.51.126.tgz: package/src/config_test.js <==
Config = require('./config.js');

const bridge1 = { id: 'id1', level: 0 }
const bridge2 = { id: 'id2', level: 0 }

config1 = {
        "operators": [1],
        "bridges": [bridge1],
        "hierarchy": [3],
        "priorities": [4],
        "associations": {
            'negative': [5],
            'positive': [6]
           },
        "version": "3",
        "description": "a",
        "objects": {'objects': 7},
        "words": {'someword': [8]},
        "floaters": [9],
        "implicits": [10],
        "flatten": [11],
        "utterances": [12],
        "generators": [13],
        "semantics": [14],

        "debug": true,
        "expected_results": [11],
        "expected_generated": [110],
        "contexts": [111],
        "skipSemantics": false,
    }

config2 = {
        "operators": [10],
        "bridges": [bridge2],
        "hierarchy": [30],
        "priorities": [40],
        "associations": {
            'negative': [50],
            'positive': [60]
           },
        "version": "3",
        "description": "b",
        "objects": {'objects': 70},
        "words": {'someword': [80]},
        "floaters": [90],
        "implicits": [100],
        "flatten": [110],
        "utterances": [120],
        "generators": [130],
        "semantics": [140],

        "debug": false,
        "expected_results": [21],
        "expected_generated": [210],
        "contexts": [211],
        "skipSemantics": true,
    }

config_1_and_2 = {
        "operators": [1, 10],
        "bridges": [bridge1, bridge2],
        "hierarchy": [3, 30],
        "priorities": [4, 40],
        "associations": {
            'negative': [5, 50],
            'positive': [6, 60]
           },
        "version": "3",
        "description": "ab",
        "expected_results": [11,21],
        "expected_generated": [110, 210],
        "objects": {'objects': 70},
        "words": {'someword': [8, 80]},
        "floaters": [9, 90],
        "implicits": [10, 100],
        "flatten": [11, 110],
        "utterances": [12, 120],
        "generators": [13, 130],
        "semantics": [14, 140],

        "debug": true,
        "expected_results": [11,21],
        "expected_generated": [110, 210],
        "contexts": [111, 211],
        "skipSemantics": true,
    }

describe('Config Tests', () => {
  it('default', () => {
    config = new Config()
  });

  it('constructor with one', () => {
    config = new Config(config1)
    expect(config.config).toStrictEqual(config1)
  });

  it('add one', () => {
    config = new Config()
    config.add(config1)
    expect(config.config).toStrictEqual(config1)
  });

  it('add two', () => {
    config = new Config()
    config.add(config1)
    config.add(config2)
    expect(config.config).toStrictEqual(config_1_and_2)
  });

  it('duplicate bridge error', () => {
    try {
      config = { "bridges": [bridge1, bridge1] }
      config = new Config(config)
      //expect(true).toBe(false)
    } catch( e ) {
      const expected = 'The operator id1/0 appears more than once in the bridges'
      expect(e).toStrictEqual(expected)
    }
  });
})

==> entodicton-5.51.133.tgz: package/src/config_test.js <==
Config = require('./config.js');

const bridge1 = { id: 'id1', level: 0 }
const bridge2 = { id: 'id2', level: 0 }

config1 = {
        "operators": [1],
        "bridges": [bridge1],
        "hierarchy": [3],
        "priorities": [4],
        "associations": {
            'negative': [5],
            'positive': [6]
           },
        "version": "3",
        "description": "a",
        "objects": {'objects': 7},
        "words": {'someword': [8]},
        "floaters": [9],
        "implicits": [10],
        "flatten": [11],
        "utterances": [12],
        "generators": [13],
        "semantics": [14],

        "debug": true,
        "expected_results": [11],
        "expected_generated": [110],
        "contexts": [111],
        "skipSemantics": false,
    }

config2 = {
        "operators": [10],
        "bridges": [bridge2],
        "hierarchy": [30],
        "priorities": [40],
        "associations": {
            'negative': [50],
            'positive': [60]
           },
        "version": "3",
        "description": "b",
        "objects": {'objects': 70},
        "words": {'someword': [80]},
        "floaters": [90],
        "implicits": [100],
        "flatten": [110],
        "utterances": [120],
        "generators": [130],
        "semantics": [140],

        "debug": false,
        "expected_results": [21],
        "expected_generated": [210],
        "contexts": [211],
        "skipSemantics": true,
    }

config_1_and_2 = {
        "operators": [1, 10],
        "bridges": [bridge1, bridge2],
        "hierarchy": [3, 30],
        "priorities": [4, 40],
        "associations": {
            'negative': [5, 50],
            'positive': [6, 60]
           },
        "version": "3",
        "description": "ab",
        "expected_results": [11,21],
        "expected_generated": [110, 210],
        "objects": {'objects': 70},
        "words": {'someword': [8, 80]},
        "floaters": [9, 90],
        "implicits": [10, 100],
        "flatten": [11, 110],
        "utterances": [12, 120],
        "generators": [13, 130],
        "semantics": [14, 140],

        "debug": true,
        "expected_results": [11,21],
        "expected_generated": [110, 210],
        "contexts": [111, 211],
        "skipSemantics": true,
    }

describe('Config Tests', () => {
  it('default', () => {
    config = new Config()
  });

  it('constructor with one', () => {
    config = new Config(config1)
    expect(config.config).toStrictEqual(config1)
  });

  it('add one', () => {
    config = new Config()
    c1 = new Config()
    config.add(c1)
    expect(c1.wasInitialized).toBe(true)
  });

  it('add two', () => {
    config = new Config()
    config.add(config1)
    config.add(config2)
    expect(config.config).toStrictEqual(config_1_and_2)
  });

  it('duplicate bridge error', () => {
    try {
      config = { "bridges": [bridge1, bridge1] }
      config = new Config(config)
      //expect(true).toBe(false)
    } catch( e ) {
      const expected = 'The operator id1/0 appears more than once in the bridges.'
      expect(e).toStrictEqual(expected)
    }
  });
})

describe('Config Initializer', () => {
  it('default', () => {
    config = new Config()
    config.initialize()
  });

  it('specified', () => {
    config = new Config()
    config.initializer( (config) => {
      config.set('dude', true)
    })
    config.initialize()
    expect(config.get('dude')).toBe(true)
  });

  it('runs only once', () => {
    config = new Config()
    config.initializer( (config) => {
      config.set('dude', true)
    })
    config.initialize()
    // this doesn't run
    config.initializer( (config) => {
      config.set('dude', false)
    })
    config.initialize()
    expect(config.get('dude')).toBe(true)
  });
})
